/**
 * Accounts list route
 *
 * @author Pierre Hubert
 */

import {
	TableContainer,
	Paper,
	Table,
	TableHead,
	TableRow,
	TableCell,
	TableBody,
} from "@material-ui/core";
import React from "react";
import { AccountHelper, AdminAccount } from "../../helpers/AccountHelper";
import { AsyncWidget } from "../widgets/AsyncWidget";
import { TimestampWidget } from "../widgets/TimestampWidget";

export class AccountsListRoute extends React.Component<
	{},
	{ version: number; list: AdminAccount[] }
> {
	constructor(p: any) {
		super(p);

		this.state = {
			version: 1,
			list: [],
		};

		this.load = this.load.bind(this);
		this.build = this.build.bind(this);
	}

	async load() {
		const list = await AccountHelper.GetAdminsList();
		this.setState({ list: list });
	}

	render() {
		return (
			<AsyncWidget
				errorMessage="Failed to load the list of adminstrators!"
				onBuild={this.build}
				key={this.state.version}
				load={this.load}
			/>
		);
	}

	build() {
		return (
			<TableContainer component={Paper}>
				<Table>
					<TableHead>
						<TableRow>
							<TableCell align="right">ID</TableCell>
							<TableCell align="right">Name</TableCell>
							<TableCell align="right">Email address</TableCell>
							<TableCell align="right">
								Account creation
							</TableCell>
						</TableRow>
					</TableHead>
					<TableBody>
						{this.state.list.map((row) => (
							<TableRow key={row.id}>
								<TableCell align="right">{row.id}</TableCell>
								<TableCell align="right">{row.name}</TableCell>
								<TableCell align="right">{row.email}</TableCell>
								<TableCell align="right">
									<TimestampWidget time={row.time_create} />
								</TableCell>
							</TableRow>
						))}
					</TableBody>
				</Table>
			</TableContainer>
		);
	}
}
